package edu.lawrence.chatclient;

import java.io.IOException;
import java.net.URL;
import java.util.Optional;
import java.util.ResourceBundle;
import javafx.application.Platform;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.control.TextInputDialog;

public class PrimaryController implements Initializable {

    private ChatGateway gateway;
    @FXML
    private TextArea textArea;
    @FXML
    private TextField comment;
           
    
    @FXML
    private void sendComment(ActionEvent event) {
        String text = comment.getText();
        gateway.sendComment(text);
    }
    
    @Override
    public void initialize(URL url, ResourceBundle rb) {
        gateway = new ChatGateway();

        // Put up a dialog to get a handle from the user
        TextInputDialog dialog = new TextInputDialog();
        dialog.setTitle("Start Chat");
        dialog.getDialogPane().setStyle("-fx-font-family: 'sans-serif'");
        dialog.setHeaderText(null);
        dialog.setContentText("Enter a handle:");

        Optional<String> result = dialog.showAndWait();
        result.ifPresent(name -> gateway.setHandle(name));

        gateway.readTranscript(textArea);
        gateway.openConnection();
        
        // Start the comment check thread
        new Thread(new CommentCheck(gateway,textArea)).start();
    }    
    
}

class CommentCheck implements Runnable {
    private ChatGateway gateway; // Gateway to the server
    private TextArea textArea; // Where to display comments
    private int N; // How many comments we have read
    
    /** Construct a thread */
    public CommentCheck(ChatGateway gateway,TextArea textArea) {
      this.gateway = gateway;
      this.textArea = textArea;
      this.N = 0;
    }

    /** Run a thread */
    public void run() {
      while(true) {
          String newComment = gateway.getComment();
          if(newComment == null) {
              try {
                  Thread.sleep(200);
              } catch(Exception ex) {}
          } else    
              Platform.runLater(()->textArea.appendText(newComment + "\n"));
      }
    }
  }
